@@ -549,21 +549,19 @@ def calculate_risk_return(ticker, start_date=None, end_date=None, sample_prices=
     if not prices:
         raise PriceError(f'No prices could be retrieved for {ticker}')
     
-    sample = len(prices)
-    # calculate sample mean annual return
-    i, mean_return, tomorrows_price = 0, 0, 0 
+    # Log of difference loses a sample
+    sample = len(prices) - 1
     logger.debug(f'Calculating mean annual return over last {sample} days for {ticker}')
 
     # NOTE: mean return is a telescoping series, i.e. sum of log(x1/x0) only depends on the first and
-    # last terms' contributions (because log(x1/x0) = log(x1) - log(x0))...which raises the question 
-    # how accurate of a measure the sample mean is of the mean rate of return for an asset?
+    # last terms' contributions (because log(x1/x0) + log(x2/x1)= log(x2) - log(x1) + log(x1) - log(x0)) = log(x2/x0))
+    # which raises the question how accurate of a measure the population mean is of the mean rate of return for an asset?
     last_price = services.parse_price_from_date(prices, list(prices)[0], asset_type)
     first_price = services.parse_price_from_date(prices, list(prices)[-1], asset_type)
     mean_return = log(float(last_price)/float(first_price))/(trading_period*sample)
     
     # calculate sample annual volatility
-    today = False
-    variance, tomorrows_price = 0, 0
+    today, variance, tomorrows_price, tomorrows_date = False, 0, 0, None
     mean_mod_return = mean_return*sqrt(trading_period)
     logger.debug(f'Calculating mean annual volatility over last {sample} days for {ticker}')
 
@@ -572,15 +570,27 @@ def calculate_risk_return(ticker, start_date=None, end_date=None, sample_prices=
 
         if today:
             logger.verbose(f'{date}: (todays_price, tomorrows_price) = ({todays_price}, {tomorrows_price})')
-            current_mod_return= log(float(tomorrows_price)/float(todays_price))/sqrt(trading_period) 
+
+            # crypto prices may have weekends and holidays removed during correlation algorithm 
+            # so samples can be compared to equities, need to account for these dates by increasing
+            # the time_delta by the number of missed days. 
+            if asset_type == settings.ASSET_CRYPTO or \
+                (asset_type == settings.ASSET_EQUITY and not helper.consecutive_trading_days(tomorrows_date, date)):
+                time_delta = (helper.parse_date_string(tomorrows_date) - helper.parse_date_string(date)).days 
+            else:
+                time_delta = 1
+
+            current_mod_return = log(float(tomorrows_price)/float(todays_price))/sqrt(time_delta*trading_period) 
             daily = (current_mod_return - mean_mod_return)**2/(sample - 1)
             variance = variance + daily
+
             logger.verbose(f'{date}: (daily_variance, sample_variance) = ({round(daily, 4)}, {round(variance, 4)})')
 
         else:
             today = True
 
         tomorrows_price = services.parse_price_from_date(prices, date, asset_type)
+        tomorrows_date = date
 
     # adjust for output
     volatility = sqrt(variance)
@@ -635,41 +645,52 @@ def calculate_ito_correlation(ticker_1, ticker_2, asset_type_1=None, asset_type_
     if correlation is not None:
         return correlation
 
-    if sample_prices is None:
-        sample_prices = {}
-        logger.debug(f'No sample prices provided or cached ({ticker_1}, {ticker_2}) correlation found.')
-        logger.debug('Retrieving price histories for calculation.')
-        prices_1 = services.get_daily_price_history(ticker=ticker_1, start_date=start_date, end_date=end_date)
-        prices_2 = services.get_daily_price_history(ticker=ticker_2, start_date=start_date, end_date=end_date)
-        sample_prices[ticker_1], sample_prices[ticker_2] = prices_1, prices_2
-
-    else:
-        logger.debug('Sample prices provided, skipping service calls.')
-        prices_1, prices_2 = sample_prices[ticker_1], sample_prices[ticker_2]
-        
-    if (not prices_1) or (not prices_2):
-        raise PriceError("Prices cannot be retrieved for correlation calculation")
-    ### END DATA RETRIEVAL ###
-    
-    ### START SAMPLE STATISTICS CALCULATION ###
-    logger.debug(f'Preparing to calculate correlation for ({ticker_1},{ticker_2})')
-    try:
-        # here I should use an adjusted function when a crypto asset is inputted. remove weekends from sample. 
-        stats_1 = calculate_risk_return(ticker_1, start_date, end_date, sample_prices[ticker_1])
-        stats_2 = calculate_risk_return(ticker_2, start_date, end_date, sample_prices[ticker_2])
-    except SampleSizeError as se:
-        raise SampleSizeError(se)
-    except PriceError as pe:
-        raise PriceError(pe)
+    ### START ARGUMENT PARSING ###
 
     if asset_type_1 is None:
         asset_type_1 = files.get_asset_type(symbol=ticker_1)
     if asset_type_2 is None:
         asset_type_2 = files.get_asset_type(symbol=ticker_2)
+
+    if start_date is None:
+        if end_date is None:
+            end_date = helper.get_last_trading_date()
+
+        start_date = helper.decrement_date_by_business_days(start_date=end_date, 
+                                                                business_days=settings.DEFAULT_ANALYSIS_PERIOD)
+
+    if sample_prices is None:
+        sample_prices = {}
+        logger.debug(f'No sample prices provided or cached ({ticker_1}, {ticker_2}) correlation found.')
+        logger.debug('Retrieving price histories for calculation.')
+        sample_prices[ticker_1] = services.get_daily_price_history(ticker=ticker_1, start_date=start_date, end_date=end_date)
+        sample_prices[ticker_2] = services.get_daily_price_history(ticker=ticker_2, start_date=start_date, end_date=end_date)
+        
+    if (len(sample_prices[ticker_1]) == 0) or (len(sample_prices[ticker_2]) == 0):
+        raise PriceError("Prices cannot be retrieved for correlation calculation")
     
+    if asset_type_1 != asset_type_2:
+        # remove weekends and holidays from crypto prices so samples can be compared
+        sample_prices[ticker_1], sample_prices[ticker_2] = helper.intersect_dict_keys(sample_prices[ticker_1], sample_prices[ticker_2])
+            
+    ### START SAMPLE STATISTICS CALCULATION ###
+    logger.debug(f'Preparing to calculate correlation for ({ticker_1},{ticker_2})')
+    try:
+        stats_1 = calculate_risk_return(ticker=ticker_1, start_date=start_date, end_date=end_date, 
+                                        sample_prices=sample_prices[ticker_1])
+        stats_2 = calculate_risk_return(ticker=ticker_2, start_date=start_date, end_date=end_date, 
+                                        sample_prices=sample_prices[ticker_2])
+    except SampleSizeError as se:
+        raise SampleSizeError(se)
+    except PriceError as pe:
+        raise PriceError(pe)
+
+    if asset_type_1 == asset_type_2 and asset_type_1 == settings.ASSET_CRYPTO:
+        trading_period = (1/365)
+    else:
+        trading_period = settings.ONE_TRADING_DAY
+        
     # ito's lemma
-    # instead of all these conditionals, use adjusted_risk_return for crypto and set period to ONE_TRADING_DAY
-    # regardless of asset types.
     if asset_type_1 == settings.ASSET_EQUITY:
         mod_mean_1 = (stats_1['annual_return'] - 0.5*(stats_1['annual_volatility'])**2)*sqrt(settings.ONE_TRADING_DAY)
     elif asset_type_1 == settings.ASSET_CRYPTO:
@@ -679,112 +700,60 @@ def calculate_ito_correlation(ticker_1, ticker_2, asset_type_1=None, asset_type_
         mod_mean_2 = (stats_2['annual_return'] - 0.5*(stats_2['annual_volatility'])**2)*sqrt(settings.ONE_TRADING_DAY)
     elif asset_type_2 == settings.ASSET_CRYPTO:
         mod_mean_2 = (stats_2['annual_return'] - 0.5*(stats_2['annual_volatility'])**2)*sqrt((1/365))
-
-    weekend_offset_1, weekend_offset_2 = 0, 0
-
-    if asset_type_1 == asset_type_2:
-        logger.debug(f'Asset({ticker_1}) and Asset({ticker_2}) are the same type of asset')
-
-        if asset_type_1 == settings.ASSET_CRYPTO:
-            trading_period = (1/365)
-        elif asset_type_1 == settings.ASSET_EQUITY:
-            trading_period = settings.ONE_TRADING_DAY
-        else:
-            trading_period = settings.ONE_TRADING_DAY
-
-    # if asset_types are different, collect # of days where one assets trades and the other does not.
-    else:
-        logger.debug(f'Asset({ticker_1}) and Asset({ticker_2}) are not the same type of asset')
-
-        # TODO: at this point, i should remove weekends from crypto prices instead of doing all of this. 
-        # create new method in services for getting only weekday crypto data. Will need to use that method to get price data for crypto assets 
-        # instead of the current way. calculate_risk_return will be affected.
-        if asset_type_1 == settings.ASSET_CRYPTO and asset_type_2 == settings.ASSET_EQUITY:
-            for date in prices_1:
-                if helper.is_date_string_weekend(date):
-                    weekend_offset_1 += 1
-            trading_period = settings.ONE_TRADING_DAY
-
-        elif asset_type_1 == settings.ASSET_EQUITY and asset_type_2 == settings.ASSET_CRYPTO:
-            for date in prices_2:
-                if helper.is_date_string_weekend(date):
-                    weekend_offset_1 += 1
-            trading_period = settings.ONE_TRADING_DAY
-
-    # make sure datasets are only compared over corresponding intervals, i.e.
-    # always calculate correlation over smallest interval.
-    # NOTE: at this point, sample_prices is only really used to iterate over date range.
-    if (len(prices_1) - weekend_offset_1) == (len(prices_2) - weekend_offset_2) \
-        or (len(prices_1) - weekend_offset_1) < (len(prices_2) - weekend_offset_2):
-        sample_prices = prices_1
-        offset = weekend_offset_1
-    else:
-        sample_prices = prices_2
-        offset = weekend_offset_2
     
-    logger.debug(f'(trading_period, offset) = ({trading_period}, {offset})')
     logger.debug(f'Calculating ({ticker_1}, {ticker_2}) correlation.')
 
     # Initialize loop variables
-    i, covariance, tomorrows_price_1, tomorrows_price_2 = 0, 0, 1, 1
-    delta = 0
-    sample = len(sample_prices)
+    i, covariance, time_delta = 0, 0, 1
+    today, tomorrows_date = False, None
+    sample = len(sample_prices[ticker_1])
 
     #### START CORRELATION LOOP ####
-
+    ### NOTE: should calculate time delta manually instead of using constant trading_period...
     ### NOTE: losing a sample affects the mean. can't use same mean. that's why inter-asset correlation is off. i think.
-    for date in sample_prices:
-        todays_price_1 = services.parse_price_from_date(prices_1, date, asset_type_1)
-        todays_price_2 = services.parse_price_from_date(prices_2, date, asset_type_2)
-        todays_date = date
-        logger.verbose(f'(todays_date, todays_price_{ticker_1}, todays_price_{ticker_2}) = ({todays_date}, {todays_price_1}, {todays_price_2})')
+    for date in sample_prices[ticker_1]:
+        todays_price_1 = services.parse_price_from_date(sample_prices[ticker_1], date, asset_type_1)
+        todays_price_2 = services.parse_price_from_date(sample_prices[ticker_2], date, asset_type_2)
+        logger.verbose(f'(todays_date, todays_price_{ticker_1}, todays_price_{ticker_2}) = ({date}, {todays_price_1}, {todays_price_2})')
             
-        # if both prices exist, proceed
-        if todays_price_1 and todays_price_2 and tomorrows_price_1 and tomorrows_price_2:
-            if i != 0: # skip first iteration
-                logger.verbose(f'Iteration #{i}')
-                logger.verbose(f'(todays_price, tomorrows_price)_{ticker_1} = ({todays_price_1}, {tomorrows_price_1})')
-                logger.verbose(f'(todays_price, tomorrows_price)_{ticker_2} = ({todays_price_2}, {tomorrows_price_2})')
-                
-                if delta != 0:
-                    logger.verbose(f'current delta = {delta}')
+        if today:
+            logger.verbose(f'Iteration #{i}')
+            logger.verbose(f'(todays_price, tomorrows_price)_{ticker_1} = ({todays_price_1}, {tomorrows_price_1})')
+            logger.verbose(f'(todays_price, tomorrows_price)_{ticker_2} = ({todays_price_2}, {tomorrows_price_2})')
 
-                time_delta = (1+delta)/sqrt(trading_period)
-                current_mod_return_1= log(float(tomorrows_price_1)/float(todays_price_1))*time_delta
-                current_mod_return_2= log(float(tomorrows_price_2)/float(todays_price_2))*time_delta
-                current_sample_covariance = (current_mod_return_1 - mod_mean_1)*(current_mod_return_2 - mod_mean_2)/(sample - 1)
-                covariance = covariance + current_sample_covariance
-            
-                logger.verbose(f'(return_1, return_2) = ({round(current_mod_return_1, 2)}, {round(current_mod_return_2, 2)})')
-                logger.verbose(f'(current_sample_covariance, covariance) = ({round(current_sample_covariance, 2)}, {round(covariance, 2)})')
-                
-                # once missed data points are skipped, annihiliate delta
-                if delta != 0:
-                    delta = 0
-                
-            i += 1
+            # crypto prices may have weekends and holidays removed during correlation algorithm 
+            # so samples can be compared to equities, need to account for these dates by increasing
+            # the time_delta by the number of missed days. 
+            if asset_type_1 == settings.ASSET_CRYPTO or \
+                (asset_type_1 == settings.ASSET_EQUITY and not helper.consecutive_trading_days(tomorrows_date, date)):
+                time_delta = (helper.parse_date_string(tomorrows_date) - helper.parse_date_string(date)).days 
+            else:
+                time_delta = 1
 
-        # if one price doesn't exist, then a data point has been lost, so revise sample. 
-        # collect number of missed data points (delta) to offset return calculation
-        else: 
-            logger.verbose('Lost a day. Revising covariance and sample.')
-            revised_covariance = covariance*(sample - 1)
-            sample -= 1 
-            
-            try:
-                covariance = revised_covariance/(sample - 1)
-            except ZeroDivisionError:
-                logger.info('Lost entire sample!')
-                return None
+            current_mod_return_1= log(float(tomorrows_price_1)/float(todays_price_1))/sqrt(time_delta*trading_period)
 
-            # accumulate lost days to adjust return
-            delta += 1
-            if i == 0:
-                i += 1
-            logger.verbose(f'(revised_covariance, revised_sample) = ({covariance}, {sample})')
+            # crypto prices may have weekends and holidays removed during correlation algorithm 
+            # so samples can be compared to equities, need to account for these dates by increasing
+            # the time_delta by the number of missed days. 
+            if asset_type_2 == settings.ASSET_CRYPTO or \
+                (asset_type_2 == settings.ASSET_EQUITY and not helper.consecutive_trading_days(tomorrows_date, date)):
+                time_delta = (helper.parse_date_string(tomorrows_date) - helper.parse_date_string(date)).days 
+            else:
+                time_delta = 1
+
+            current_mod_return_2= log(float(tomorrows_price_2)/float(todays_price_2))/sqrt(time_delta*trading_period)
+
+            current_sample_covariance = (current_mod_return_1 - mod_mean_1)*(current_mod_return_2 - mod_mean_2)/(sample - 1)
+            covariance = covariance + current_sample_covariance
         
-        tomorrows_price_1 = services.parse_price_from_date(prices_1, date, asset_type_1)
-        tomorrows_price_2 = services.parse_price_from_date(prices_2, date, asset_type_2)
+            logger.verbose(f'(return_1, return_2) = ({round(current_mod_return_1, 2)}, {round(current_mod_return_2, 2)})')
+            logger.verbose(f'(current_sample_covariance, covariance) = ({round(current_sample_covariance, 2)}, {round(covariance, 2)})')
+                
+        else:
+            today = True
+        
+        i += 1
+        tomorrows_price_1, tomorrows_price_2, tomorrows_date = todays_price_1, todays_price_2, date
     #### END CORRELATION LOOP ####
 
     # Scale covariance into correlation
